summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ssl
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/ssl')
-rw-r--r--chrome/browser/ssl/ssl_add_cert_handler.cc2
-rw-r--r--chrome/browser/ssl/ssl_cert_error_handler.cc2
-rw-r--r--chrome/browser/ssl/ssl_client_auth_handler.cc4
-rw-r--r--chrome/browser/ssl/ssl_client_auth_handler.h4
-rw-r--r--chrome/browser/ssl/ssl_error_handler.cc18
-rw-r--r--chrome/browser/ssl/ssl_error_handler.h16
-rw-r--r--chrome/browser/ssl/ssl_manager.cc2
-rw-r--r--chrome/browser/ssl/ssl_manager.h2
8 files changed, 26 insertions, 24 deletions
diff --git a/chrome/browser/ssl/ssl_add_cert_handler.cc b/chrome/browser/ssl/ssl_add_cert_handler.cc
index 668df59..e2356af 100644
--- a/chrome/browser/ssl/ssl_add_cert_handler.cc
+++ b/chrome/browser/ssl/ssl_add_cert_handler.cc
@@ -14,7 +14,7 @@
#include "net/base/x509_certificate.h"
#include "net/url_request/url_request.h"
-SSLAddCertHandler::SSLAddCertHandler(URLRequest* request,
+SSLAddCertHandler::SSLAddCertHandler(net::URLRequest* request,
net::X509Certificate* cert,
int render_process_host_id,
int render_view_id)
diff --git a/chrome/browser/ssl/ssl_cert_error_handler.cc b/chrome/browser/ssl/ssl_cert_error_handler.cc
index b3d7f87..40bf067 100644
--- a/chrome/browser/ssl/ssl_cert_error_handler.cc
+++ b/chrome/browser/ssl/ssl_cert_error_handler.cc
@@ -11,7 +11,7 @@
SSLCertErrorHandler::SSLCertErrorHandler(
ResourceDispatcherHost* rdh,
- URLRequest* request,
+ net::URLRequest* request,
ResourceType::Type resource_type,
const std::string& frame_origin,
const std::string& main_frame_origin,
diff --git a/chrome/browser/ssl/ssl_client_auth_handler.h b/chrome/browser/ssl/ssl_client_auth_handler.h
index 4680602..a1de68e 100644
--- a/chrome/browser/ssl/ssl_client_auth_handler.h
+++ b/chrome/browser/ssl/ssl_client_auth_handler.h
@@ -19,7 +19,7 @@ class X509Certificate;
// This class handles the approval and selection of a certificate for SSL client
// authentication by the user.
// It is self-owned and deletes itself when the UI reports the user selection or
-// when the URLRequest is cancelled.
+// when the net::URLRequest is cancelled.
class SSLClientAuthHandler
: public base::RefCountedThreadSafe<SSLClientAuthHandler,
BrowserThread::DeleteOnIOThread> {
@@ -54,7 +54,7 @@ class SSLClientAuthHandler
// Called on the IO thread.
void DoCertificateSelected(net::X509Certificate* cert);
- // The URLRequest that triggered this client auth.
+ // The net::URLRequest that triggered this client auth.
net::URLRequest* request_;
// The certs to choose from.
diff --git a/chrome/browser/ssl/ssl_error_handler.h b/chrome/browser/ssl/ssl_error_handler.h
index 104e9b5..7d4a9cf 100644
--- a/chrome/browser/ssl/ssl_error_handler.h
+++ b/chrome/browser/ssl/ssl_error_handler.h
@@ -28,7 +28,7 @@ class URLRequest;
// UI thread. Subclasses should override the OnDispatched/OnDispatchFailed
// methods to implement the actions that should be taken on the UI thread.
// These methods can call the different convenience methods ContinueRequest/
-// CancelRequest to perform any required action on the URLRequest the
+// CancelRequest to perform any required action on the net::URLRequest the
// ErrorHandler was created with.
//
// IMPORTANT NOTE:
@@ -41,7 +41,7 @@ class SSLErrorHandler : public base::RefCountedThreadSafe<SSLErrorHandler> {
public:
virtual SSLCertErrorHandler* AsSSLCertErrorHandler() { return NULL; }
- // Find the appropriate SSLManager for the URLRequest and begin handling
+ // Find the appropriate SSLManager for the net::URLRequest and begin handling
// this error.
//
// Call on UI thread.
@@ -63,24 +63,24 @@ class SSLErrorHandler : public base::RefCountedThreadSafe<SSLErrorHandler> {
// called from the UI thread.
TabContents* GetTabContents();
- // Cancels the associated URLRequest.
+ // Cancels the associated net::URLRequest.
// This method can be called from OnDispatchFailed and OnDispatched.
void CancelRequest();
- // Continue the URLRequest ignoring any previous errors. Note that some
+ // Continue the net::URLRequest ignoring any previous errors. Note that some
// errors cannot be ignored, in which case this will result in the request
// being canceled.
// This method can be called from OnDispatchFailed and OnDispatched.
void ContinueRequest();
- // Cancels the associated URLRequest and mark it as denied. The renderer
+ // Cancels the associated net::URLRequest and mark it as denied. The renderer
// processes such request in a special manner, optionally replacing them
// with alternate content (typically frames content is replaced with a
// warning message).
// This method can be called from OnDispatchFailed and OnDispatched.
void DenyRequest();
- // Does nothing on the URLRequest but ensures the current instance ref
+ // Does nothing on the net::URLRequest but ensures the current instance ref
// count is decremented appropriately. Subclasses that do not want to
// take any specific actions in their OnDispatched/OnDispatchFailed should
// call this.
@@ -107,7 +107,7 @@ class SSLErrorHandler : public base::RefCountedThreadSafe<SSLErrorHandler> {
// Should only be accessed on the UI thread.
SSLManager* manager_; // Our manager.
- // The id of the URLRequest associated with this object.
+ // The id of the net::URLRequest associated with this object.
// Should only be accessed from the IO thread.
GlobalRequestID request_id_;
@@ -150,7 +150,7 @@ class SSLErrorHandler : public base::RefCountedThreadSafe<SSLErrorHandler> {
// This read-only member can be accessed on any thread.
const std::string main_frame_origin_;
- // A flag to make sure we notify the URLRequest exactly once.
+ // A flag to make sure we notify the net::URLRequest exactly once.
// Should only be accessed on the IO thread
bool request_has_been_notified_;
diff --git a/chrome/browser/ssl/ssl_manager.cc b/chrome/browser/ssl/ssl_manager.cc
index abb5a1a..f874cc0 100644
--- a/chrome/browser/ssl/ssl_manager.cc
+++ b/chrome/browser/ssl/ssl_manager.cc
@@ -24,7 +24,7 @@
// static
void SSLManager::OnSSLCertificateError(ResourceDispatcherHost* rdh,
- URLRequest* request,
+ net::URLRequest* request,
int cert_error,
net::X509Certificate* cert) {
DVLOG(1) << "OnSSLCertificateError() cert_error: " << cert_error
diff --git a/chrome/browser/ssl/ssl_manager.h b/chrome/browser/ssl/ssl_manager.h
index d45fe8c..0c61596 100644
--- a/chrome/browser/ssl/ssl_manager.h
+++ b/chrome/browser/ssl/ssl_manager.h
@@ -42,7 +42,7 @@ class SSLManager : public NotificationObserver {
// Entry point for SSLCertificateErrors. This function begins the process
// of resolving a certificate error during an SSL connection. SSLManager
// will adjust the security UI and either call |Cancel| or
- // |ContinueDespiteLastError| on the URLRequest.
+ // |ContinueDespiteLastError| on the net::URLRequest.
//
// Called on the IO thread.
static void OnSSLCertificateError(ResourceDispatcherHost* resource_dispatcher,
diff --git a/chrome/browser/ssl/ssl_client_auth_handler.cc b/chrome/browser/ssl/ssl_client_auth_handler.cc
index 2081f33..159c1ed 100644
--- a/chrome/browser/ssl/ssl_client_auth_handler.cc
+++ b/chrome/browser/ssl/ssl_client_auth_handler.cc
@@ -11,7 +11,7 @@
#include "net/url_request/url_request.h"
SSLClientAuthHandler::SSLClientAuthHandler(
- URLRequest* request,
+ net::URLRequest* request,
net::SSLCertRequestInfo* cert_request_info)
: request_(request),
cert_request_info_(cert_request_info) {
@@ -39,7 +39,7 @@ void SSLClientAuthHandler::SelectCertificate() {
// If the RVH does not exist by the time this task gets run, then the task
// will be dropped and the scoped_refptr to SSLClientAuthHandler will go
// away, so we do not leak anything. The destructor takes care of ensuring
// the URLRequest always gets a response.
CallRenderViewHostSSLDelegate(
render_process_host_id, render_view_host_id,
&RenderViewHostDelegate::SSL::ShowClientCertificateRequestDialog,
@@ -39,7 +39,7 @@ void SSLClientAuthHandler::SelectCertificate() {
// will be dropped and the scoped_refptr to SSLClientAuthHandler will go
// away, so we do not leak anything. The destructor takes care of ensuring
- // the URLRequest always gets a response.
+ // the net::URLRequest always gets a response.
CallRenderViewHostSSLDelegate(
render_process_host_id, render_view_host_id,
diff --git a/chrome/browser/ssl/ssl_error_handler.cc b/chrome/browser/ssl/ssl_error_handler.cc
index d05c17f..7f90bac 100644
--- a/chrome/browser/ssl/ssl_error_handler.cc
+++ b/chrome/browser/ssl/ssl_error_handler.cc
@@ -14,7 +14,7 @@
#include "net/url_request/url_request.h"
SSLErrorHandler::SSLErrorHandler(ResourceDispatcherHost* rdh,
- URLRequest* request,
+ net::URLRequest* request,
ResourceType::Type resource_type,
const std::string& frame_origin,
const std::string& main_frame_origin)
@@ -39,7 +39,7 @@ SSLErrorHandler::SSLErrorHandler(ResourceDispatcherHost* rdh,
NOTREACHED();
// This makes sure we don't disappear on the IO thread until we've given an
// answer to the URLRequest.
//
// Release in CompleteCancelRequest, CompleteContinueRequest, or
// CompleteTakeNoAction.
@@ -119,14 +119,15 @@ void SSLErrorHandler::TakeNoAction() {
void SSLErrorHandler::CompleteCancelRequest(int error) {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
// It is important that we notify the URLRequest only once. If we try to
// notify the request twice, it may no longer exist and |this| might have
// already have been deleted.
DCHECK(!request_has_been_notified_);
if (request_has_been_notified_)
return;
- URLRequest* request = resource_dispatcher_host_->GetURLRequest(request_id_);
+ net::URLRequest* request =
+ resource_dispatcher_host_->GetURLRequest(request_id_);
if (request) {
// The request can be NULL if it was cancelled by the renderer (as the
// result of the user navigating to a new page from the location bar).
@@ -146,14 +147,15 @@ void SSLErrorHandler::CompleteCancelRequest(int error) {
void SSLErrorHandler::CompleteContinueRequest() {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
// It is important that we notify the URLRequest only once. If we try to
// notify the request twice, it may no longer exist and |this| might have
// already have been deleted.
DCHECK(!request_has_been_notified_);
if (request_has_been_notified_)
return;
- URLRequest* request = resource_dispatcher_host_->GetURLRequest(request_id_);
+ net::URLRequest* request =
+ resource_dispatcher_host_->GetURLRequest(request_id_);
if (request) {
// The request can be NULL if it was cancelled by the renderer (as the
// result of the user navigating to a new page from the location bar).
@@ -169,7 +171,7 @@ void SSLErrorHandler::CompleteContinueRequest() {
void SSLErrorHandler::CompleteTakeNoAction() {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
// It is important that we notify the URLRequest only once. If we try to
// notify the request twice, it may no longer exist and |this| might have
// already have been deleted.
DCHECK(!request_has_been_notified_);
@@ -39,7 +39,7 @@ SSLErrorHandler::SSLErrorHandler(ResourceDispatcherHost* rdh,
NOTREACHED();
// This makes sure we don't disappear on the IO thread until we've given an
- // answer to the URLRequest.
+ // answer to the net::URLRequest.
//
// Release in CompleteCancelRequest, CompleteContinueRequest, or
@@ -119,14 +119,15 @@ void SSLErrorHandler::TakeNoAction() {
void SSLErrorHandler::CompleteCancelRequest(int error) {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
- // It is important that we notify the URLRequest only once. If we try to
- // notify the request twice, it may no longer exist and |this| might have
+ // It is important that we notify the net::URLRequest only once. If we try
+ // to notify the request twice, it may no longer exist and |this| might have
// already have been deleted.
DCHECK(!request_has_been_notified_);
@@ -146,14 +147,15 @@ void SSLErrorHandler::CompleteCancelRequest(int error) {
void SSLErrorHandler::CompleteContinueRequest() {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
- // It is important that we notify the URLRequest only once. If we try to
+ // It is important that we notify the net::URLRequest only once. If we try to
// notify the request twice, it may no longer exist and |this| might have
// already have been deleted.
@@ -169,7 +171,7 @@ void SSLErrorHandler::CompleteContinueRequest() {
void SSLErrorHandler::CompleteTakeNoAction() {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
- // It is important that we notify the URLRequest only once. If we try to
+ // It is important that we notify the net::URLRequest only once. If we try to
// notify the request twice, it may no longer exist and |this| might have
// already have been deleted.